---
name: Bug
about: Bug report
title: ''
labels: ''
assignees: ''

---

**Describe the bug**

A clear and concise description of what the bug is.

**Steps/Code to reproduce bug**

Please list *minimal* steps or code snippet for us to be able to reproduce the bug.

A  helpful guide on on how to craft a minimal bug report  http://matthewrocklin.com/blog/work/2018/02/28/minimal-bug-reports. 

**Expected behavior**

A clear and concise description of what you expected to happen.

**Configs**
NeMo Gym (e.g. via `ng_dump_config`) or RL training framework config files.

**Environment details**

Otherwise, please provide:
- OS version
- Python version
- `uv pip list` output

**Additional context**

Add any other context about the problem here.
Example: GPU model
